import 'package:flutter/material.dart';

import 'package:random/models/game_data.dart';
import 'package:random/ui/painters/cell_painter.dart';

class GameBoardWidget extends StatelessWidget {
  const GameBoardWidget({
    super.key,
    required this.gameData,
    required this.size,
    required this.animations,
  });

  final GameData gameData;
  final Size size;
  final List<List<Animation<double>?>> animations;

  @override
  Widget build(BuildContext context) {
    final widgetWidth = this.size.width;
    final widgetHeight = this.size.height;

    final rowsCount = this.gameData.board.length;
    final columnsCount = this.gameData.board[0].length;

    final cellWidth = widgetWidth / columnsCount;
    final cellHeight = widgetHeight / rowsCount;

    final List<Widget> cells = [];

    for (var y = 0; y < rowsCount; y++) {
      for (var x = 0; x < columnsCount; x++) {
        final GameDataItem item = this.gameData.board[y][x];
        int? value = item.value;

        if (value != null) {
          final Animation<double>? translation = this.animations[y][x];

          final Widget cellContent = CustomPaint(
            size: Size(cellWidth, cellHeight),
            willChange: false,
            painter: CellPainter(value: value),
          );

          final Widget cellWidget = Positioned(
            left: (x * cellWidth).toDouble(),
            top: ((y + (translation?.value ?? 0)) * cellHeight).toDouble(),
            child: Container(
              width: cellWidth,
              height: cellHeight,
              child: cellContent,
            ),
          );

          cells.add(cellWidget);
        }
      }
    }

    return Container(
      width: widgetWidth,
      height: widgetHeight,
      color: Colors.black,
      child: Stack(
        children: cells,
      ),
    );
  }
}
