import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:random/cubit/data_cubit.dart';
import 'package:random/cubit/api_cubit.dart';
import 'package:random/cubit/settings_cubit.dart';
import 'package:random/models/interface_type.dart';

class AppHeader extends StatelessWidget {
  const AppHeader({super.key, required this.text});

  final String text;

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          tr(text),
          textAlign: TextAlign.start,
          style: Theme.of(context).textTheme.headlineMedium!.apply(fontWeightDelta: 2),
        ),
        SizedBox(width: 2),
        expertInterfaceIndicator(),
        SizedBox(width: 2),
        dataCounterIndicator(),
        SizedBox(width: 2),
        apiLoadingIndicator(),
      ],
    );
  }

  Widget expertInterfaceIndicator() {
    return BlocBuilder<SettingsCubit, SettingsState>(
      builder: (BuildContext context, SettingsState settingsState) {
        bool isExpert = settingsState.interfaceType == InterfaceType.expert;

        return Text(isExpert ? '⭐' : '');
      },
    );
  }

  Widget dataCounterIndicator() {
    return BlocBuilder<DataCubit, DataState>(
      builder: (context, dataState) {
        return Text('(' + dataState.counter.toString() + ')');
      },
    );
  }

  Widget apiLoadingIndicator() {
    return BlocBuilder<ApiDataCubit, ApiDataState>(
      builder: (context, apiDataState) {
        return (apiDataState is ApiDataFetchLoading)
            ? Text('⏳')
            : (apiDataState is ApiDataFetchLoaded)
                ? Text('✅')
                : Text('⚠️');
      },
    );
  }
}
